@@ -2,6 +2,8 @@ import os
 import json
 import tempfile
 import threading
+import requests
+import frictionless
 
 from flask import make_response, request
 
@@ -260,20 +262,23 @@ def publish_package():
     }
     metadata = data['metadata']
     try:
-        get_action('package_patch')(context, package_data)
-        frictionless_package = get_action('generate_datapackage_json')(context, package_data)
+        package_data = get_action('package_patch')(context, package_data)
     except ValidationError as e:
         data_response['errors'] = e.error_dict
         data_response['error_summary'] = e.error_summary
         data_response['has_error'] = True
     else:
         def _validate():
+            admin = model.Session.query(model.User).filter(model.User.sysadmin==True).first()
+            session = requests.Session()
+            session.headers['Authorization'] = admin.apikey
             site_url = config.get('ckan.site_url')
             if site_url.endswith('/'):
                 url = f"{site_url}datapackage-creator/show-datapackage-json/{data['id']}"
             else:
                 url = f"{site_url}/datapackage-creator/show-datapackage-json/{data['id']}"
-            validation = default_backend.validate_package(url)
+            with frictionless.system.use_http_session(session) as ctx:
+                validation = frictionless.validate(url)
             datapackage = model.Session.query(Datapackage).filter(
                 Datapackage.package_id==package_data['id']
             ).order_by(Datapackage.created.desc()).first()
@@ -300,26 +305,31 @@ def datapackage_show(package_id):
         'user': toolkit.c.user,
         'auth_user_obj': toolkit.c.userobj,
         'api_version': 3,
+        'id': package_id,
+    }
+    data = {
+        'id': package_id
     }
     try:
-        toolkit.check_access('package_show', context)
+        toolkit.check_access('package_show', context, data)
     except toolkit.NotAuthorized:
         toolkit.abort(401, toolkit._('Unauthorized to create a dataset'))
     response = make_response()
     response.content_type = 'application/json'
     data = {
-        'package_id': package_id
+        'id': package_id
     }
     try:
+        package = get_action('package_show')(context, data)
+        data = {
+            'package_id': package['id']
+        }
         datapackage = get_action('datapackage_show')(context, data)
     except Exception as ex:
         datapackage = Datapackage()
-    data = {
-        'id': package_id
-    }
-    package = get_action('package_show')(context, data)
     datapackage_json = row_to_dict(datapackage)
     datapackage_json['errors_json'] = datapackage.errors_json()
+    datapackage_json['data_json'] = datapackage.data_json()
     data_response = {
         'datapackage': datapackage_json,
         'package': package,
@@ -336,10 +346,6 @@ def datapackage_resource_show(resource_id):
         'auth_user_obj': toolkit.c.userobj,
         'api_version': 3,
     }
-    try:
-        toolkit.check_access('package_show', context)
-    except toolkit.NotAuthorized:
-        toolkit.abort(401, toolkit._('Unauthorized to create a dataset'))
     response = make_response()
     response.content_type = 'application/json'
     data = {
@@ -362,11 +368,12 @@ def datapackage_resource_show(resource_id):
 
 
 def datapackage_json_show(package_id):
+    admin = model.Session.query(model.User).filter(model.User.sysadmin==True, model.User.name!='default').first()
     context = {
         'model': model,
         'session': model.Session,
-        'user': toolkit.c.user,
-        'auth_user_obj': toolkit.c.userobj,
+        'user': admin.name,
+        'auth_user_obj': admin,
         'api_version': 3,
     }
     data = {
