@@ -10,8 +10,18 @@ var app = new Vue({
         settings: null,
         loading_message: 'Loading...',
         loading: false,
-        package: {
-
+        package: {},
+        file_icons: {
+            pdf: 'pdf.png',
+            jpg: 'jpg.png',
+            jpeg: 'jpg.png',
+            png: 'png.png',
+            doc: 'doc.png',
+            docx: 'doc.png',
+            json: 'json.png',
+            txt: 'txt.png',
+            rar: 'rar.png',
+            zip: 'zip.png'
         },
         resources: [
             {
@@ -32,7 +42,8 @@ var app = new Vue({
                 has_error: false,
                 error_summary: [],
                 errors: {},
-                extras: []
+                extras: [],
+                file_icon: 'default.png'
             }
         ],
         typeFieldOptions: [
@@ -147,8 +158,7 @@ var app = new Vue({
         let resourceId = this.$refs.resourceId.value
         if(resourceId) {
             this.allowed_add_resource = false
-            this.resources[0].id = resourceId
-            this.getResource()
+            this.getResource(resourceId)
         } else {
             this.getPackage()
         }
@@ -169,7 +179,7 @@ var app = new Vue({
                 this.package.visibility = res.data.package.private
                 this.package.source = res.data.package.url || ''
                 this.package.version = res.data.package.version
-                let datapackage = JSON.parse(res.data.datapackage.data)
+                let datapackage = JSON.parse(res.data.datapackage.data_json)
                 this.package.contributors = datapackage.contributors
                 this.package.tags = datapackage.tags
                 this.package.frequency = datapackage.frequency
@@ -177,14 +187,15 @@ var app = new Vue({
                 this.package.metadata = datapackage
             })
         },
-        getResource() {
-            const url = `/datapackage-creator/show-datapackage-resource/${this.resources[0].id}`
+        getResource(resourceId) {
+            const url = `/datapackage-creator/show-datapackage-resource/${resourceId}`
             this.loading = true
             axios.get(url).then(res => {
                 this.loading = false
                 this.package_id = res.data.resource.package_id
                 this.resources = []
                 this.resources.push(JSON.parse(res.data.datapackage_resource.data))
+                this.resources[0].id = resourceId
                 this.getPackage()
             }).catch(() => {
                 this.loading = false
@@ -213,6 +224,7 @@ var app = new Vue({
                         resource.error_summary = []
                         resource.has_error = false
                         resource.inference = res.data
+                        console.log(res.data)
                         resource.name = resource.inference.metadata.name
                         resource.encoding = resource.inference.metadata.encoding
                         resource.format = resource.inference.metadata.format
@@ -375,7 +387,8 @@ var app = new Vue({
                     current_field: [],
                     has_error: false,
                     error_summary: [],
-                    errors: {}
+                    errors: {},
+                    extras: []
                 }
             )
         },
@@ -409,6 +422,7 @@ var app = new Vue({
             })
         },
         validate(){
+            this.$refs["success-message"].scrollIntoView({ behavior: "smooth" })
             this.allowed_publish = true
             this.resources.forEach(resource => {
                 this.saveResource(resource)
@@ -472,6 +486,10 @@ var app = new Vue({
                 }
                 return true
             })
+        },
+        getFileIcon(format) {
+            let icon =  this.file_icons[format]
+            return icon ? icon : 'default.png'
         }
     },
     computed: {
